require(ape, quietly = TRUE)
bird.families <- read.tree("bird.families.tre")
